'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var parse5 = require('parse5');

async function processLiterals(strings, ...exps) {
    const listTask = exps.map(async (n) => {
        const tasks = (Array.isArray(n) ? n : [n])
            .map(async (o) => 'function' === typeof (o) ? o() : o);
        return Promise.all(tasks);
    });
    const done = await Promise.all(listTask);
    const doneLen = done.length;
    return strings.reduce((p, n, i) => {
        const nTask = done[i];
        const joined = Array.isArray(nTask) ? nTask.join('') : nTask;
        return `${p}${i >= doneLen ? n : `${n}${joined}`}`;
    }, '');
}
async function parsePartial(fn, strings, ...exps) {
    try {
        const content = await processLiterals(strings, ...exps);
        return parse5.serialize(fn(content));
    }
    catch (e) {
        throw e;
    }
}
const html = async (s, ...e) => parsePartial(c => parse5.parse(`<!doctype html>${c}`), s, ...e);
const htmlFragment = async (s, ...e) => parsePartial(parse5.parseFragment, s, ...e);
var index = { html, htmlFragment };

exports.default = index;
exports.html = html;
exports.htmlFragment = htmlFragment;
//# sourceMappingURL=index.js.map
